# filesr  


## Installation  

```sh
$ npm install filesr  
```

## Usage  
```html
<form action="/profile" method="post" enctype="multipart/form-data">
  <input type="file" name="avatar" />
</form>
```

```javascript
var express = require('express')
var upfile  = require('upfilesr')
var upload = upfile('public/uploads/')

var app = express()

app.post('/profile', upload.single('avatar'), function (req, res, next) {
  // req.file is the `avatar` file
  // req.body will hold the text fields, if there were any
})

app.post('/photos/upload', upload.array('photos', 12), function (req, res, next) {
  // req.files is array of `photos` files
  // req.body will contain the text fields, if there were any
})

var cpUpload = upload.fields([{ name: 'avatar', maxCount: 1 }, { name: 'gallery', maxCount: 8 }])
app.post('/cool-profile', cpUpload, function (req, res, next) {
  // req.files is an object (String -> Array) where fieldname is the key, and the value is array of files
  //
  // e.g.
  //  req.files['avatar'][0] -> File
  //  req.files['gallery'] -> Array
  //
  // req.body will contain the text fields, if there were any
})
```

## API  

### File information  

Each file contains the following information:  

Key | Description | Note  
--- | --- | ---
`fieldname` | Field name specified in the form |  
`originalname` | Name of the file on the user's computer |  
`encoding` | Encoding type of the file |  
`mimetype` | Mime type of the file |  
`size` | Size of the file in bytes |  
`destination` | The folder to which the file has been saved | `DiskStorage`  
`filename` | The name of the file within the `destination` | `DiskStorage`  
`path` | The full path to the uploaded file | `DiskStorage`  
`buffer` | A `Buffer` of the entire file | `MemoryStorage`  


### delete file
```javascript
	upload.deleteFile(paths,fn(data))
```